import{s as de,n as he,o as fe}from"../chunks/scheduler.c59d9fbb.js";import{S as pe,i as ce,g as o,s,r as O,A as ue,h as r,f as n,c as a,j as le,u as G,x as l,k as me,y as ge,a as i,v as J,d as K,t as N,w as Q}from"../chunks/index.a47918e3.js";import{H as V}from"../chunks/Heading.604bc707.js";function ve(W){let m,k,_,q,d,F,h,X="SetFit is a model framework to efficiently train text classification models with surprisingly little training data. For example, with only 8 labeled examples per class on the Customer Reviews (CR) sentiment dataset, SetFit is competitive with fine-tuning RoBERTa Large on the full training set of 3k examples. Furthermore, SetFit is fast to train and run inference with, and can easily support multilingual tasks.",P,f,Y="Every SetFit model consists of two parts: a <strong>sentence transformer</strong> embedding model (the body) and a <strong>classifier</strong> (the head). These two parts are trained in two separate phases: the <strong>embedding finetuning phase</strong> and the <strong>classifier training phase</strong>. This conceptual guide will elaborate on the intuition between these phases, and why SetFit works so well.",S,p,H,c,Z='The first phase has one primary goal: finetune a sentence transformer embedding model to produce useful embeddings for <em>our</em> classification task. The <a href="https://huggingface.co/models?library=sentence-transformers" rel="nofollow">Hugging Face Hub</a> already has thousands of sentence transformer available, many of which have been trained to very accurately group the embeddings of texts with similar semantic meaning.',L,u,ee="However, models that are good at Semantic Textual Similarity (STS) are not necessarily immediately good at <em>our</em> classification task. For example, according to an embedding model, the sentence of 1) <code>&quot;He biked to work.&quot;</code> will be much more similar to 2) <code>&quot;He drove his car to work.&quot;</code> than to 3) <code>&quot;Peter decided to take the bicycle to the beach party!&quot;</code>. But if our classification task involves classifying texts into transportation modes, then we want our embedding model to place sentences 1 and 3 closely together, and 2 further away.",M,g,te="To do so, we can finetune the chosen sentence transformer embedding model. The goal here is to nudge the model to use its pretrained knowledge in a different way that better aligns with our classification task, rather than making the completely forget what it has learned.",E,v,ne="For finetuning, SetFit uses <strong>contrastive learning</strong>. This training approach involves creating <strong>positive and negative pairs</strong> of sentences. A sentence pair will be positive if both of the sentences are of the same class, and negative otherwise. For example, in the case of binary “positive”-“negative” sentiment analysis, <code>(&quot;The movie was awesome&quot;, &quot;I loved it&quot;)</code> is a positive pair, and <code>(&quot;The movie was awesome&quot;, &quot;It was quite disappointing&quot;)</code> is a negative pair.",j,w,ie="During training, the embedding model receives these pairs, and will convert the sentences to embeddings. If the pair is positive, then it will pull on the model weights such that the text embeddings will be more similar, and vice versa for a negative pair. Through this approach, sentences with the same label will be embedded more similarly, and sentences with different labels less similarly.",R,b,se="Conveniently, this contrastive learning works with pairs rather than individual samples, and we can create plenty of unique pairs from just a few samples. For example, given 8 positive sentences and 8 negative sentences, we can create 28 positive pairs and 64 negative pairs for 92 unique training pairs. This grows exponentially to the number of sentences and classes, and that is why SetFit can train with just a few examples and still correctly finetune the sentence transformer embedding model. However, we should still be wary of overfitting.",U,y,z,x,ae="Once the sentence transformer embedding model has been finetuned for our task at hand, we can start training the classifier. This phase has one primary goal: create a good mapping from the sentence transformer embeddings to the classes.",A,T,oe="Unlike with the first phase, training the classifier is done from scratch and using the labeled samples directly, rather than using pairs. By default, the classifier is a simple <strong>logistic regression</strong> classifier from scikit-learn. First, all training sentences are fed through the now-finetuned sentence transformer embedding model, and then the sentence embeddings and labels are used to fit the logistic regression classifier. The result is a strong and efficient classifier.",B,C,re="Using these two parts, SetFit models are efficient, performant and easy to train, even on CPU-only devices.",I,$,D;return d=new V({props:{title:"Sentence Transformers Finetuning (SetFit)",local:"sentence-transformers-finetuning-setfit",headingTag:"h1"}}),p=new V({props:{title:"Embedding finetuning phase",local:"embedding-finetuning-phase",headingTag:"h2"}}),y=new V({props:{title:"Classifier training phase",local:"classifier-training-phase",headingTag:"h2"}}),{c(){m=o("meta"),k=s(),_=o("p"),q=s(),O(d.$$.fragment),F=s(),h=o("p"),h.textContent=X,P=s(),f=o("p"),f.innerHTML=Y,S=s(),O(p.$$.fragment),H=s(),c=o("p"),c.innerHTML=Z,L=s(),u=o("p"),u.innerHTML=ee,M=s(),g=o("p"),g.textContent=te,E=s(),v=o("p"),v.innerHTML=ne,j=s(),w=o("p"),w.textContent=ie,R=s(),b=o("p"),b.textContent=se,U=s(),O(y.$$.fragment),z=s(),x=o("p"),x.textContent=ae,A=s(),T=o("p"),T.innerHTML=oe,B=s(),C=o("p"),C.textContent=re,I=s(),$=o("p"),this.h()},l(e){const t=ue("svelte-u9bgzb",document.head);m=r(t,"META",{name:!0,content:!0}),t.forEach(n),k=a(e),_=r(e,"P",{}),le(_).forEach(n),q=a(e),G(d.$$.fragment,e),F=a(e),h=r(e,"P",{"data-svelte-h":!0}),l(h)!=="svelte-7242ph"&&(h.textContent=X),P=a(e),f=r(e,"P",{"data-svelte-h":!0}),l(f)!=="svelte-51qtkz"&&(f.innerHTML=Y),S=a(e),G(p.$$.fragment,e),H=a(e),c=r(e,"P",{"data-svelte-h":!0}),l(c)!=="svelte-dbktaq"&&(c.innerHTML=Z),L=a(e),u=r(e,"P",{"data-svelte-h":!0}),l(u)!=="svelte-1hxwo6o"&&(u.innerHTML=ee),M=a(e),g=r(e,"P",{"data-svelte-h":!0}),l(g)!=="svelte-zryalp"&&(g.textContent=te),E=a(e),v=r(e,"P",{"data-svelte-h":!0}),l(v)!=="svelte-1nefhuw"&&(v.innerHTML=ne),j=a(e),w=r(e,"P",{"data-svelte-h":!0}),l(w)!=="svelte-1kn883t"&&(w.textContent=ie),R=a(e),b=r(e,"P",{"data-svelte-h":!0}),l(b)!=="svelte-guljow"&&(b.textContent=se),U=a(e),G(y.$$.fragment,e),z=a(e),x=r(e,"P",{"data-svelte-h":!0}),l(x)!=="svelte-x8nyyj"&&(x.textContent=ae),A=a(e),T=r(e,"P",{"data-svelte-h":!0}),l(T)!=="svelte-1uv4jmo"&&(T.innerHTML=oe),B=a(e),C=r(e,"P",{"data-svelte-h":!0}),l(C)!=="svelte-1vdh750"&&(C.textContent=re),I=a(e),$=r(e,"P",{}),le($).forEach(n),this.h()},h(){me(m,"name","hf:doc:metadata"),me(m,"content",we)},m(e,t){ge(document.head,m),i(e,k,t),i(e,_,t),i(e,q,t),J(d,e,t),i(e,F,t),i(e,h,t),i(e,P,t),i(e,f,t),i(e,S,t),J(p,e,t),i(e,H,t),i(e,c,t),i(e,L,t),i(e,u,t),i(e,M,t),i(e,g,t),i(e,E,t),i(e,v,t),i(e,j,t),i(e,w,t),i(e,R,t),i(e,b,t),i(e,U,t),J(y,e,t),i(e,z,t),i(e,x,t),i(e,A,t),i(e,T,t),i(e,B,t),i(e,C,t),i(e,I,t),i(e,$,t),D=!0},p:he,i(e){D||(K(d.$$.fragment,e),K(p.$$.fragment,e),K(y.$$.fragment,e),D=!0)},o(e){N(d.$$.fragment,e),N(p.$$.fragment,e),N(y.$$.fragment,e),D=!1},d(e){e&&(n(k),n(_),n(q),n(F),n(h),n(P),n(f),n(S),n(H),n(c),n(L),n(u),n(M),n(g),n(E),n(v),n(j),n(w),n(R),n(b),n(U),n(z),n(x),n(A),n(T),n(B),n(C),n(I),n($)),n(m),Q(d,e),Q(p,e),Q(y,e)}}}const we='{"title":"Sentence Transformers Finetuning (SetFit)","local":"sentence-transformers-finetuning-setfit","sections":[{"title":"Embedding finetuning phase","local":"embedding-finetuning-phase","sections":[],"depth":2},{"title":"Classifier training phase","local":"classifier-training-phase","sections":[],"depth":2}],"depth":1}';function be(W){return fe(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class Ce extends pe{constructor(m){super(),ce(this,m,be,ve,de,{})}}export{Ce as component};
